"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const inversify_1 = require("inversify");
const cluster = require("cluster");
const colors = require("colors");
const os = require("os");
const exceptions_1 = require("nowjs-core/lib/exceptions");
const index_1 = require("../common/index");
const Logger_1 = require("./Logger");
const mlogger = Logger_1.getLauncherLogger();
const kernel = new inversify_1.Container();
function getKernel() {
    return kernel;
}
exports.getKernel = getKernel;
function startUpWorker(application, options) {
    if (cluster.isWorker || process.env.NODE_ENV === index_1.ENV_DEVELOPMENT_TOKEN) {
        const appName = options.AppName;
        application.start();
    }
}
function startUp(application, options) {
    kernel.bind(index_1.TYPES.Kernel).toConstantValue(kernel);
    if (process.env.NODE_ENV === index_1.ENV_DEVELOPMENT_TOKEN) {
        startUpWorker(application, options);
    }
    else {
        if (cluster.isMaster) {
            for (let i = 0; i < Math.min(os.cpus().length, options.WorkerLimit); i++) {
                const worker = cluster.fork(process.env);
                worker.on("disconnect", () => {
                });
                worker.on("online", () => {
                });
                worker.on("error", (code, signal) => {
                });
                worker.on("exit", (code, signal) => {
                });
            }
            cluster.on("exit", (worker, code, signal) => {
                mlogger.error(`worker ${worker.process.pid} died.`, code, signal);
            });
        }
        else {
            if (process.env.NODE_ENV !== index_1.ENV_DEVELOPMENT_TOKEN) {
                startUpWorker(application, options);
            }
        }
    }
}
function boot(application, options) {
    if (!options) {
        throw new exceptions_1.CodedException(-1104, "App options can not be null.");
    }
    const appName = options.AppName || process.env.npm_package_name;
    const appVersion = process.env.npm_package_version;
    let banner = `\n\nThe '${colors.yellow(appName)}' application is ${colors.bold("loading")} in pid: ${process.pid}.`;
    banner += `\n\t\t${colors.green("************************************************************************")}`;
    banner += `\n\t\t\t\t ${colors.bold(colors.yellow("Nowjs Boot loader v1.4.0"))
        + "\t" + colors.green("pid:" + process.pid)}`;
    banner += `\n\t\t\t\t\t ${colors.bold(colors.red("www.NowCanDo.com"))}`;
    banner += `\n\t\t${colors.green("************************************************************************")}`;
    banner += `\nThe '${colors.yellow(appName)}' application environment has been set to ${colors.blue("Mode")}='${options.Mode}' , ${colors.blue("ClusterMode")}='${cluster.isMaster ? "Master" : "Worker"}' ,  ${colors.blue("RunningMode")}='${process.env.NODE_ENV === index_1.ENV_DEVELOPMENT_TOKEN ? "Development" : "Production"}' ,  ${colors.blue("WorkerLimit")}='${options.WorkerLimit}' , ${colors.blue("LogLevel")}='${options.LogLevel}' .`;
    banner += `\nThe ${colors.magenta("System")} environment is ${colors.blue("Os")}='${os.platform()} / ${os.type()} / ${os.arch()} / ${os.release()}' ,  ${colors.blue("OsUpTime")}='${os.uptime()}' ,  ${colors.blue("HostName")}='${os.hostname}' , ${colors.blue("Cpu")}='${os.cpus().length} / ${os.cpus()[0].model} / ${os.cpus()[0].speed}' ,  ${colors.blue("Memory")}='${Math.ceil(os.totalmem() / (1024 * 1024))} MB / ${Math.ceil(os.freemem() / (1024 * 1024))} MB'  , ${colors.blue("LoadAverage")}='${os.loadavg()}'`;
    banner += `, ${colors.magenta("Nodejs")}='${process.version}'  , ${colors.blue("Cwd")}='${process.cwd()}' .`;
    banner += `\n\n`;
    process.on("unhandledRejection", (err, p) => {
        mlogger.error(`There is a unhandeled promise rejection :\n${err.message}`, err, p);
        process.exit(2);
    });
    process.on("uncaughtException", (err) => {
        mlogger.error(`There is a unhandeled error :\n${err.message}`, err);
        process.exit(2);
    });
    try {
        mlogger.info(banner);
        startUp(application, options);
    }
    catch (error) {
        throw error;
    }
}
exports.boot = boot;
