"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const os = require("os");
const exceptions_1 = require("nowjs-core/lib/exceptions");
const index_1 = require("./boot/index");
const index_2 = require("./common/index");
function boot(application, options) {
    const logger = index_1.getLauncherLogger();
    logger.info("Nowjs launcher starting ...");
    try {
        const envAppMode = process.env.NOWJS_APP_MODE;
        const envWorkerLimit = process.env.NOWJS_APP_WORKERLIMIT;
        const envLogLevel = process.env.NOWJS_APP_LOGLEVEL;
        const defaultLevel = process.env.NODE_ENV === index_2.ENV_DEVELOPMENT_TOKEN ? "debug" : "info";
        const defaultWorkerLimit = process.env.NODE_ENV === index_2.ENV_DEVELOPMENT_TOKEN ? 1 : os.cpus().length;
        const defaultMode = "standalone";
        const workerLimit = envWorkerLimit ? parseInt(envWorkerLimit) :
            process.argv.indexOf("--worker-limit") >= 0 ?
                parseInt(process.argv[process.argv.indexOf("--worker-limit") + 1]) :
                defaultWorkerLimit;
        const logLevel = envLogLevel || process.argv.indexOf("--log-level") >= 0 ?
            process.argv[process.argv.indexOf("--log-level") + 1] : defaultLevel;
        const mode = envAppMode || process.argv.indexOf("--mode") >= 0 ?
            process.argv[process.argv.indexOf("--mode") + 1] : defaultMode;
        options = Object.assign(options || {}, {
            LogLevel: logLevel.toLowerCase(),
            Mode: mode.toLowerCase(),
            WorkerLimit: workerLimit,
        });
        const bootstrap = require("./boot/Bootstrap");
        if (bootstrap) {
            bootstrap.boot(application, options);
        }
        else {
            throw new exceptions_1.CodedException(-1101, "The kernel bootstrap not loaded.");
        }
    }
    catch (error) {
        logger.error(error.toString());
        throw error;
    }
    finally {
    }
}
exports.boot = boot;
